==> google-cloud-build-3.14.0.tar.gz: google-cloud-build-3.14.0/google/cloud/devtools/cloudbuild_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .cloudbuild import (
    OperationMetadata,
    RunWorkflowCustomOperationMetadata,
)
from .repositories import (
    BatchCreateRepositoriesRequest,
    BatchCreateRepositoriesResponse,
    Connection,
    CreateConnectionRequest,
    CreateRepositoryRequest,
    DeleteConnectionRequest,
    DeleteRepositoryRequest,
    FetchLinkableRepositoriesRequest,
    FetchLinkableRepositoriesResponse,
    FetchReadTokenRequest,
    FetchReadTokenResponse,
    FetchReadWriteTokenRequest,
    FetchReadWriteTokenResponse,
    GetConnectionRequest,
    GetRepositoryRequest,
    GitHubConfig,
    GitHubEnterpriseConfig,
    InstallationState,
    ListConnectionsRequest,
    ListConnectionsResponse,
    ListRepositoriesRequest,
    ListRepositoriesResponse,
    OAuthCredential,
    Repository,
    ServiceDirectoryConfig,
    UpdateConnectionRequest,
)

__all__ = (
    "OperationMetadata",
    "RunWorkflowCustomOperationMetadata",
    "BatchCreateRepositoriesRequest",
    "BatchCreateRepositoriesResponse",
    "Connection",
    "CreateConnectionRequest",
    "CreateRepositoryRequest",
    "DeleteConnectionRequest",
    "DeleteRepositoryRequest",
    "FetchLinkableRepositoriesRequest",
    "FetchLinkableRepositoriesResponse",
    "FetchReadTokenRequest",
    "FetchReadTokenResponse",
    "FetchReadWriteTokenRequest",
    "FetchReadWriteTokenResponse",
    "GetConnectionRequest",
    "GetRepositoryRequest",
    "GitHubConfig",
    "GitHubEnterpriseConfig",
    "InstallationState",
    "ListConnectionsRequest",
    "ListConnectionsResponse",
    "ListRepositoriesRequest",
    "ListRepositoriesResponse",
    "OAuthCredential",
    "Repository",
    "ServiceDirectoryConfig",
    "UpdateConnectionRequest",
)

==> google-cloud-build-3.22.0.tar.gz: google-cloud-build-3.22.0/google/cloud/devtools/cloudbuild_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .cloudbuild import OperationMetadata, RunWorkflowCustomOperationMetadata
from .repositories import (
    BatchCreateRepositoriesRequest,
    BatchCreateRepositoriesResponse,
    Connection,
    CreateConnectionRequest,
    CreateRepositoryRequest,
    DeleteConnectionRequest,
    DeleteRepositoryRequest,
    FetchGitRefsRequest,
    FetchGitRefsResponse,
    FetchLinkableRepositoriesRequest,
    FetchLinkableRepositoriesResponse,
    FetchReadTokenRequest,
    FetchReadTokenResponse,
    FetchReadWriteTokenRequest,
    FetchReadWriteTokenResponse,
    GetConnectionRequest,
    GetRepositoryRequest,
    GitHubConfig,
    GitHubEnterpriseConfig,
    GitLabConfig,
    InstallationState,
    ListConnectionsRequest,
    ListConnectionsResponse,
    ListRepositoriesRequest,
    ListRepositoriesResponse,
    OAuthCredential,
    ProcessWebhookRequest,
    Repository,
    ServiceDirectoryConfig,
    UpdateConnectionRequest,
    UserCredential,
)

__all__ = (
    "OperationMetadata",
    "RunWorkflowCustomOperationMetadata",
    "BatchCreateRepositoriesRequest",
    "BatchCreateRepositoriesResponse",
    "Connection",
    "CreateConnectionRequest",
    "CreateRepositoryRequest",
    "DeleteConnectionRequest",
    "DeleteRepositoryRequest",
    "FetchGitRefsRequest",
    "FetchGitRefsResponse",
    "FetchLinkableRepositoriesRequest",
    "FetchLinkableRepositoriesResponse",
    "FetchReadTokenRequest",
    "FetchReadTokenResponse",
    "FetchReadWriteTokenRequest",
    "FetchReadWriteTokenResponse",
    "GetConnectionRequest",
    "GetRepositoryRequest",
    "GitHubConfig",
    "GitHubEnterpriseConfig",
    "GitLabConfig",
    "InstallationState",
    "ListConnectionsRequest",
    "ListConnectionsResponse",
    "ListRepositoriesRequest",
    "ListRepositoriesResponse",
    "OAuthCredential",
    "ProcessWebhookRequest",
    "Repository",
    "ServiceDirectoryConfig",
    "UpdateConnectionRequest",
    "UserCredential",
)
